aboutsummaryrefslogtreecommitdiffstats
path: root/simulation
diff options
context:
space:
mode:
Diffstat (limited to 'simulation')
-rw-r--r--simulation/app.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/simulation/app.go b/simulation/app.go
index c312204..40aa32b 100644
--- a/simulation/app.go
+++ b/simulation/app.go
@@ -94,9 +94,9 @@ func (a *simApp) getAckedBlocks(ackHash common.Hash) (output common.Hashes) {
return
}
-// PreparePayloads implements core.Application.
-func (a *simApp) PreparePayloads(position types.Position) [][]byte {
- return [][]byte{}
+// PreparePayload implements core.Application.
+func (a *simApp) PreparePayload(position types.Position) []byte {
+ return []byte{}
}
// StronglyAcked is called when a block is strongly acked by DEXON